@@ -1,12 +1,15 @@
+import os
 from all.logging import DummyWriter
 from all.experiments import SingleEnvExperiment, ParallelEnvExperiment
 
 class TestSingleEnvExperiment(SingleEnvExperiment):
-    def _make_writer(self, agent_name, env_name, write_loss):
+    def _make_writer(self, logdir, agent_name, env_name, write_loss):
+        os.makedirs(logdir, exist_ok=True)
         return DummyWriter()
 
 class TestParallelEnvExperiment(ParallelEnvExperiment):
-    def _make_writer(self, agent_name, env_name, write_loss):
+    def _make_writer(self, logdir, agent_name, env_name, write_loss):
+        os.makedirs(logdir, exist_ok=True)
         return DummyWriter()
 
 def validate_agent(agent, env):
